@@ -1,4 +1,3 @@
-from io import StringIO
 import json
 import os
 import signal
@@ -36,7 +35,7 @@ notifier = [None]
 
 def notify(app, msg, **kw):
     app.info('NOTIF: %s' % msg, **kw)
-    if notifier[0] == None:
+    if notifier[0] is None:
         notifier[0] = False
         for n in 'dunstify', 'notify-send':
             if os.system('type %s 1>/dev/null 2>/dev/null' % n) == 0:
@@ -46,7 +45,7 @@ def notify(app, msg, **kw):
         return
     try:
         subprocess.Popen([notifier[0], msg, '\n' + kvmsg(kw)])
-    except:
+    except Exception:
         pass
 
 
@@ -79,6 +78,9 @@ class App:
     def error(self, msg, **kw):
         kvprint('ERR ', msg, kw)
 
+    def fatal(self, msg, **kw):
+        kvprint('DIE ', msg, kw)
+
     def notify(self, msg, **kw):
         notify(App, msg, **kw)
 
@@ -140,7 +142,7 @@ def set_dirs():
 
     if db and os.path.exists(db):
         p = os.environ['PATH']
-        if not db + ':' in p:
+        if db + ':' not in p:
             os.environ['PATH'] = db + ':' + p
 
 
@@ -161,8 +163,11 @@ def set_app(name, log):
     # [setattr(app, k, v) for k, v in dirs(name).items()]
     # allows raise app.die(msg, **kw):
 
-    def die(msg, **kw):
+    def die(msg, silent=False, **kw):
         """Application decided to bail out"""
+        if silent:
+            app.fatal(msg, **kw)
+            sys.exit(1)
         raise DieNow(msg, kw)
 
     app.die = die
@@ -203,7 +208,6 @@ def init_app_parse_flags(*args):
     tools.set_flag_vals_from_env()
     kw_log = {}
     sl.setup_logging(**kw_log)
-    breakpoint()   # FIXME BREAKPOINT
     log = sl.get_logger(name)
     set_app(name, log)
 
@@ -275,7 +279,7 @@ def run_app(
             argv=argv,
             flags_parser=flags_parser,
         )
-    except Exception as ex:
+    except Exception:
         sys.exit(1)
 
 
@@ -288,7 +292,7 @@ def define_action_flags_in_cli():
         p += 1
         if a == '--':
             return
-        if not a in afs:
+        if a not in afs:
             continue
         if p > 1:
             pa = args[p - 1]
@@ -452,7 +456,6 @@ def reload_handler(signum, frame):
 
 
 def run_phase_2(args, name, main, kw_log, flags_validator, wrapper):
-
     tools.set_flag_vals_from_env()  # 0.0001sec
 
     if FLG.help_call:
@@ -464,7 +467,7 @@ def run_phase_2(args, name, main, kw_log, flags_validator, wrapper):
         call_doc(main, level=3, render=True)
         return
 
-    kw_log = {} if kw_log == None else kw_log
+    kw_log = {} if kw_log is None else kw_log
     if flags_validator:
         try:
             err = flags_validator()
@@ -516,7 +519,7 @@ def run_phase_2(args, name, main, kw_log, flags_validator, wrapper):
         except DieNow as ex:
             app.error(ex.msg, exc=ex, **ex.kw)
             raise
-        except Reloaded as ex:
+        except Reloaded:
             continue
         except SystemExit as ex:
             return ex.args[0]
@@ -540,7 +543,7 @@ def run_phase_2(args, name, main, kw_log, flags_validator, wrapper):
                 [p() for p in post] if isinstance(post, list) else post()
         break
     if not isinstance(res, (list, dict, tuple)):
-        if not res is None:
+        if res is not None:
             print(res)
         return
     # exit phase. postprocessing, pretty to stdout, plain to | jq .:
