@@ -1,6 +1,8 @@
-from devapp.tools import offset_port, exists, project
+from devapp.tools import offset_port, exists, project, write_file
+import platform
 import os
 from devapp.app import app
+# from devapp.operations import binenv, asdf
 
 
 class tool:
@@ -24,8 +26,16 @@ def redis_server(**kw):
     return m
 
 
+def fake_rotatelogs_presence(pth):
+    """Up to now we did not find a proper replacement for the linuy only http tools of kalefranz"""
+    os.makedirs(pth, exist_ok=True)
+    write_file(pth + '/rotatelogs', '', chmod=0o755)
+
+
 def verify_tools(path, rsc, **kw):
     for p in rsc.provides:
+        if p == 'rotatelogs' and platform.system() != 'Linux':
+            fake_rotatelogs_presence(path)
         d = path + '/' + p
         if not exists(d):
             app.error('Not found', cmd=d)
@@ -42,9 +52,19 @@ def lc_tools(*a, **kw):
     return cmd
 
 
+def slc(**kw):
+    os.environ.get('slc_lc_hubs')
+    return {'cmd': ':ops slc connect'}
+
+
 class rsc:
     """For services we change dir to project."""
 
+    class slc:
+        cmd = slc
+        pkg = False
+        environ = ['lc_hubs']
+
     class redis_server:
         provides = ['redis-server', 'redis-cli']
         cmd = 'redis-server'
@@ -72,3 +92,7 @@ class rsc:
         conda_chan = 'kalefranz'
         conda_pkg = 'httpd'
         verify_present = verify_tools
+
+
+# rsc.binenv = binenv.binenv
+# rsc.asdf = asdf.asdf
