@@ -7,7 +7,7 @@ import json
 import os
 import re
 import sys
-
+import operator
 from devapp import tools
 from devapp.app import app
 from tree_builder import full_id
@@ -20,6 +20,8 @@ fidstr = lambda r: r['___']  # stored here to show up top
 
 postprocs = {'': lambda v: v, 'json.dumps': json.dumps}
 
+Vault = {}
+
 
 class SmartAdapt:
     """processing the context render hits on cls.<key>"""
@@ -41,7 +43,7 @@ class SmartAdapt:
         r, m = self.r, self.r
         k, dflt = (k + '|' + nil).split('|')[:2]
         ko = k
-        if not '.' in k:
+        if '.' not in k:
             if k.startswith('v:'):
                 return Vault.get(r, k[2:])
             k = 'env.' + k
@@ -174,7 +176,9 @@ class API:
         """TODO: support central token stores, Vault
         secret at is ignored, too shaky with spec dependent hub names
         """
-        import jwt, time, uuid
+        import jwt
+        import time
+        import uuid
 
         # independent of hub name:
         s = r['env']['DA_DIR'] + '/secure/token_secret'
@@ -189,13 +193,13 @@ class API:
         kw['why'] = kw.get('why', 'build')
         return jwt.encode(kw, s, algorithm='HS256').decode('utf-8')
 
-    # links = Links
-    @staticmethod
-    def lazy(*a, **kw):
-        "provide a cache for user funcs, e.g. the ssh key read"
-        # not overwrite our own stuff:
-        # TODO: take from old axc2:
-        return c_lazy('user_api_' + a[0], *a[1:], **kw)
+    # # links = Links
+    # @staticmethod
+    # def lazy(*a, **kw):
+    #     "provide a cache for user funcs, e.g. the ssh key read"
+    #     # not overwrite our own stuff:
+    #     # TODO: take from old axc2:
+    #     return c_lazy('user_api_' + a[0], *a[1:], **kw)
 
     @classmethod
     def _into(cls, g):
