@@ -2,10 +2,11 @@
 """
 Ansi Escape Tools for Terminal Output
 
-Note: This was written while I did not yet realize the base16 term indirection,
-I.e. global shell themes.
+Note: This was written while I did not yet realize the 16 color term indirection,
+I.e. global cross app shell themes.
 Meanwhile I don't think, hardcoded colorthemes per app should even exist.
 """
+
 from __future__ import absolute_import, division, print_function
 
 import os
@@ -13,7 +14,7 @@ import sys
 import time
 from collections import OrderedDict
 from functools import partial
-
+from theming.colorhilite import formatter_by_style
 from theming.unicode_chars import blocks
 
 # https://misc.flogisoft.com/bash/tip_colors_and_formatting
@@ -22,7 +23,10 @@ from theming.unicode_chars import blocks
 if sys.version_info[0] > 2:
     char = chr
 else:
-    char = lambda nr: unichr(nr).encode('utf-8')
+
+    def char(nr):
+        return unichr(nr).encode('utf-8')
+
 
 envget = os.environ.get
 
@@ -57,7 +61,7 @@ class Theme:
 
     # fmt:off
     I = [11, 'Important', 'Titles, H1, New contexts']
-    G = [2, 'Green', 'OK, H2, Success']
+    G = [4, 'Green', 'OK, H2, Success']
     M = [1, 'Marked UP', 'Sub Titles, H3, Important values in dicts']
     R = [124, 'Red', 'Alarm, Error, Warning, Failed']
     L = [5, 'Low Intensity', 'Debug Output, Code, Shell output']
@@ -114,12 +118,12 @@ class Theme:
         defined in python can be sourced
         (i.e. reversing the definition order, we normally use the shell theme)
         """
-        raise NotImplemented
+        raise NotImplementedError
 
     @classmethod
     def attrs(cls):
         """Other attributes of the Theme"""
-        c = cls.color_keys()
+        cls.color_keys()
         r = {'name': cls.__name__}
         for k in dir(cls):
             if k.startswith('_'):
@@ -165,7 +169,7 @@ class Theme:
         while s:
             c, s = s[0], s[1:]
             r.append(c) if hasattr(cls, c) else 0
-        [r.append(c) for c in dir(cls) if not c in r and cls.is_col_key(c)]
+        [r.append(c) for c in dir(cls) if c not in r and cls.is_col_key(c)]
         return r
 
     @classmethod
@@ -192,7 +196,7 @@ class Theme:
             cf = FLG.log_fmt
             if cf in {'2', 2, 'plain'}:
                 cls.force_colors = True
-        except:
+        except Exception:
             pass
 
         def col_def(k, v, dt='Unnamed %s Color', tt='<Untagged>'):
@@ -248,7 +252,10 @@ class Theme:
     @classmethod
     def color_prefixes(cls):
         """returns just the prefix w/o the reset at the end"""
-        d = lambda k: getattr(cls, k.lower())('XX').split('XX')[0]
+
+        def d(k):
+            return getattr(cls, k.lower())('XX').split('XX')[0]
+
         return dict([(k, d(k)) for k in cls.color_keys()])
 
     @classmethod
@@ -338,7 +345,7 @@ class Cell:
         """
         try:
             symb = char(_chars[nr % _lchars])
-        except:
+        except Exception:
             symb, nr = nr, hash(nr)
         return Cell.colorize(symb, nr)
 
@@ -356,31 +363,60 @@ def unique_str(s):
     return Cell.colorize(s, nr=hash(s))
 
 
-def structlog_style():
+def add_ax_pygm_style():
+    from pygments import styles
+
+    def fst(fn):
+        return fn.rsplit('/', 1)[0] + '/ax_pygm.py'
+
+    if not os.path.exists(fst(styles.__file__)):
+        os.symlink(fst(__file__), fst(styles.__file__))
+
+    styles.STYLE_MAP['ax'] = 'ax_pygm::AXDarkStyle'
+
+
+def structlog_style(use_pygm=None):
     """for structlog init w/o colorama (e.g. ax.rx)"""
-    #  structlog/dev.py
-    C = Theme.color_prefixes()
+    style, F = formatter_by_style(use_pygm)
+    if not F or style in {'dark', 'light'}:
+        C = Theme.color_prefixes()
+        C['RB'] = C['R']
+    else:
+        ss = F.style_string  # noqa: F841
+        # ss['Token.Error'] = ss['Token.Generic.Error']
+        # ss['Token.String.Double'] = tuple( ['"%s"' % i for i in ss['Token.Literal.String.Double']]
+        C = {}
+        l = [
+            'R Generic.Error',
+            'I Name.Class',
+            'M Keyword.Constant',
+            'L Name.Other',
+            'D Comment',
+            'G Literal.String',
+        ]
+        for _ in l:
+            k, v = _.split(' ')
+            C[k] = ss['Token.%s' % v][0] or '\x1b[0m'
+        C['RB'] = ss['Token.Error'][0] or ss['Token.Generic.Error'][0]
 
     # fmt:off
     def style(orig_style):
         class S(orig_style):
-            level_critical = level_exception = level_error = C['R']
-            level_warn  = C['I']
-            level_info  = C['M']
-            level_debug = C['L']
             timestamp   = C['D']
             logger_name = C['L']
             kv_key      = C['M']
-            kv_value    = C['I']
+            kv_value    = C['D']
             reset       = RESET
 
         return S
 
     ls = {
-        'critical'  : C['R'],
-        'exception' : C['R'],
-        'error'     : C['R'],
-        'warn'      : C['I'],
+        'fatal'     : C['RB'],
+        'critical'  : C['RB'],
+        'exception' : C['RB'],
+        'error'     : C['RB'],
+        'err'       : C['RB'],
+        'warn'      : C['R'],
         'warning'   : C['R'],
         'info'      : C['G'],
         'debug'     : C['L'],
@@ -430,6 +466,7 @@ def structlog_style():
 #    }
 #
 
+
 # -------------------------------------------------------- oldish 8 color stuff
 # TODO gk: check if we can ditch all below:
 class ShellColors:
